package fdf;

import com.foxit.gsdk.PDFException;
import com.foxit.gsdk.pdf.PDFDocument;
import com.foxit.gsdk.pdf.PDFPage;
import com.foxit.gsdk.pdf.Progress;
import com.foxit.gsdk.utils.FileHandler;

import common.Common;

public class fdf
{
	// load Foxit PDF Library
	static
	   {
	      try
	      {
	        String name = System.getProperty("os.name");
	        String arch = System.getProperty("os.arch");
	        System.out.println("os.name = " + name);
	        System.out.println("os.arch = " + arch);
	           if (name.toLowerCase().startsWith("win"))//windows
	        {
	             if (arch.contains("64"))
	           {
	                System.load(System.getProperty("user.dir") + "//lib//fsdk_java_win64.dll");
	           }
	             else {
	                System.load(System.getProperty("user.dir") + "//lib//fsdk_java_win32.dll");
	           }
	        }
	           else {//linux
	           if (arch.contains("64"))
	              System.load(System.getProperty("user.dir") + "/lib/libfsdk_java_linux64.so");
	           else {
	              System.load(System.getProperty("user.dir") + "/lib/libfsdk_java_linux32.so");
	           }
	        }

	      }
	      catch (UnsatisfiedLinkError e)
	      {
	        System.out.println("Native code library failed to load.\n" + e);
	        System.exit(1);
	      }
	   }

	/* The default page size */
	private static float pageWidth		= 612;
	private static float pageHeight 	= 792;
	public static void main(String[] args)
	{		
		Common common = new Common();
		
		String inputFloder = "../testfiles/";
		String outputFloder = "../output_files/fdf";
		Common.createFloder(outputFloder);
		
		//open and write log
		Common.openLog(outputFloder + "/log.txt");
		Common.outputLog("Foxit PDF Linux JAVA SDK example: fdf");
		
		common.initlize();
		
		//import annotations from FDF to PDF
		String fdfName = "AnnotationData.fdf";
		importAnnotsFromFDF(fdfName, inputFloder, outputFloder);
		
		//Export annotations from PDF to FDF
		String pdfName = "AnnotationDataExport.pdf";
		exportAnnotsToFDF(pdfName, inputFloder, outputFloder);
		
		//release
		common.release();
		//close log file
		Common.closeLog();
	}

	public static void importAnnotsFromFDF(String fdfName, String inputPath, String outputPath)
	{
		FileHandler fdfFile;
		try
		{
			fdfFile = FileHandler.create(inputPath + fdfName, FileHandler.FILEMODE_READONLY);
			String pdfName = fdfName.substring(0, fdfName.length() - 4) + ".pdf";
			PDFDocument pdfDocument = Common.createDocument();
			PDFPage page = pdfDocument.createPage(0);
			page.setSize(pageWidth, pageHeight);
			pdfDocument.importAnnotsFromFDF(fdfFile);
			Common.outputLog("Success: Import annotations from FDF document file.");
			Common.saveDocument(pdfDocument, outputPath + "/" + pdfName);
			
			fdfFile.release();
			pdfDocument.closePage(page);
			pdfDocument.close();
		}
		catch (PDFException e)
		{
			e.printStackTrace();
			Common.outputErrMsg(e.getLastError(), "Failed to import annotations from FDF document file.");
		}
		
	}
	
	public static void exportAnnotsToFDF(String pdfName, String inputPath, String outputPath)
	{
		try
		{
			PDFDocument pdfDocument = Common.openDocument(inputPath + pdfName, null);
			String fdfName = pdfName.substring(0, pdfName.length() - 4) + ".fdf";
			FileHandler fdfFile = FileHandler.create(outputPath + "/" + fdfName, FileHandler.FILEMODE_TRUNCATE);
			pdfDocument.exportAnnotsToFDF(inputPath + pdfName, fdfFile);
			Common.outputLog("Success: Export annotations to FDF document file.");
			Progress progress = pdfDocument.startSaveToFile(fdfFile, PDFDocument.SAVEFLAG_OBJECTSTREAM);
			if (progress != null)
			{
				int ret = Progress.TOBECONTINUED;
				while (Progress.TOBECONTINUED == ret)
				{
					ret = progress.continueProgress(30);
				}
				progress .release();
			}
			
			fdfFile.release();
			pdfDocument.close();
		}
		catch (PDFException e)
		{
			e.printStackTrace();
			Common.outputErrMsg(e.getLastError(), "Failed to export annotations to FDF document file.");
		}
	}
}
