package mt_watermark;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

public class Main
{
	public static void main(String[] args) throws IOException
	{
		//use default path
		String inputSrcFile = "../testfiles/";
		String [] filePath = new String[] {inputSrcFile + "AboutFoxit.pdf",
				inputSrcFile + "PageLabels.pdf",
				inputSrcFile + "Bookmark.pdf",
				inputSrcFile + "AnnotationDataExport.pdf",
				inputSrcFile + "InsertPages.pdf"};
		//it is an element of the ProcessBuilder's command, it must not be not null.
		String password = "";
		String className = WatermarkProc.class.getName();
		//Create a thread pool.
		ExecutorService executor = Executors.newCachedThreadPool();	
		for (int i = 0; i < 5; i++)
		{
			WatermarkThread wmThread = new WatermarkThread(filePath[i], password, className);
			executor.execute(wmThread);
		}
		executor.shutdown();
		try
		{
			while (!executor.awaitTermination(10, TimeUnit.SECONDS));
		}
		catch (InterruptedException e1)
		{
			e1.printStackTrace();
		}
	}

}


class WatermarkThread implements Runnable
{
	private String filePath = null;
	private String password = null;
	//get java.exe or java path
    private String java = System.getProperty("java.home") + File.separator + "bin" + File.separator + "java";  
    //get java process path
    private String classpath = System.getProperty("java.class.path");
    //
    private String className = null;
    
    private List<String> command = new ArrayList<String>();//the element of command list must not be null.
    
	public WatermarkThread(String filePath, String password, String className)
	{
		this.filePath = filePath;
		this.password = password;
		this.className = className;
	}
	
	private void setCommand()
	{
		if (this.className == null)
		{
			System.out.println("Please input the class name of the java process");
			return;
		}
		command.add(java);
		command.add("-classpath");  
	    command.add(classpath);  
	    command.add(this.className);
	    command.add(this.filePath);
	    command.add(this.password);
	}
	
	public void run()
	{
		try
		{
			doWatermark();
		}
		catch (IOException e)
		{
			e.printStackTrace();
		}
		catch (ClassNotFoundException e)
		{
			e.printStackTrace();
		}
		catch (NoSuchMethodException e)
		{
			e.printStackTrace();
		}
		catch (InvocationTargetException e)
		{
			e.printStackTrace();
		}
	}
	
	public void doWatermark() throws IOException, ClassNotFoundException, NoSuchMethodException, InvocationTargetException
	{
  
	    ProcessBuilder pb = null;  
	    Process process = null;  

		//add command parameters
		setCommand();	    
	    pb = new ProcessBuilder(command);  
	    long statTime = System.currentTimeMillis();
	    process = pb.start();  
	    //print the log from WatermarkProc.java
	    Scanner scanner = new Scanner(process.getInputStream());

        while (scanner.hasNextLine()) {
        	System.out.println(Thread.currentThread().getName() + ": " + scanner.nextLine());
        }
        scanner.close();
        long endTime = System.currentTimeMillis();
        System.out.println(Thread.currentThread().getName() + " run time: " + (endTime - statTime) + "ms");
	}
}
