package signature;

import com.foxit.gsdk.PDFException;
import com.foxit.gsdk.image.Image;
import com.foxit.gsdk.pdf.PDFDocument;
import com.foxit.gsdk.pdf.PDFPage;
import com.foxit.gsdk.pdf.Progress;
import com.foxit.gsdk.pdf.signature.Signature;
import com.foxit.gsdk.pdf.signature.Signature.KeyStoreInfo;
import com.foxit.gsdk.utils.FileHandler;
import com.foxit.gsdk.utils.RectF;

import common.Common;

public class signature {
	// load Foxit PDF Library
	static
	   {
	      try
	      {
	        String name = System.getProperty("os.name");
	        String arch = System.getProperty("os.arch");
	        System.out.println("os.name = " + name);
	        System.out.println("os.arch = " + arch);
	           if (name.toLowerCase().startsWith("win"))//windows
	        {
	             if (arch.contains("64"))
	           {
	                System.load(System.getProperty("user.dir") + "//lib//fsdk_java_win64.dll");
	           }
	             else {
	                System.load(System.getProperty("user.dir") + "//lib//fsdk_java_win32.dll");
	           }
	        }
	           else {//linux
	           if (arch.contains("64"))
	              System.load(System.getProperty("user.dir") + "/lib/libfsdk_java_linux64.so");
	           else {
	              System.load(System.getProperty("user.dir") + "/lib/libfsdk_java_linux32.so");
	           }
	        }

	      }
	      catch (UnsatisfiedLinkError e)
	      {
	        System.out.println("Native code library failed to load.\n" + e);
	        System.exit(1);
	      }
	   }
	
		public static void main(String[] args)
		{
			Common common = new Common();
			
			String inputSrcFile = "../testfiles/AboutFoxit.pdf";
			String inputCertFile = "../testfiles/foxit_all.pfx";
			String certFileKey = "123";
			String outputFloder = "../output_files/signature";
			int leng = args.length;
			//Judge if to command line arguments. 
			//usage:java signature <srcfile> <certfile> <certkey>
			if (args.length == 1)
			{
				inputSrcFile = args[0];
				if (!Common.fileExist(inputSrcFile))
				{
					Common.outputLog("Failed: The input file is not exist!");
					System.exit(1);
				}
			}
			else if (args.length == 2)
			{
				inputSrcFile = args[0];
				Common.outputLog("Failed: The password of certificate file is not specified!");
				System.exit(1);
			}
			else if (args.length > 2)
			{
				inputSrcFile = args[0];
				inputCertFile = args[1];
				certFileKey = args[2];
				
				if (!Common.fileExist(inputSrcFile) || !Common.fileExist(inputCertFile))
				{
					Common.outputLog("Failed: The input file is not exist!");
					System.exit(1);
				}
			}
			
			if(!Common.folderExist(outputFloder))
				Common.createFloder(outputFloder);
			
			//open and write
			Common.openLog(outputFloder + "/log.txt");
			Common.outputLog("Foxit PDF Linux JAVA SDK example: signature");
			
			common.initlize();	
			signPDF(inputSrcFile, inputCertFile, certFileKey, outputFloder);
			
			Common.outputLog("Success: Sign PDF document file.");
			//release the resource		
			common.release();
			//close log file
			Common.closeLog();
		}

		private static void signPDF(String inputSrcFile, String inputCertFile,
				String certFileKey, String outputFloder) {
			// TODO Auto-generated method stub
			try {
				Signature.registerDefaultHandler();
				PDFDocument document = Common.openDocument(inputSrcFile, null);
				PDFPage page = document.getPage(0);
				FileHandler imageFile = FileHandler.create("../testfiles/foxit-SDK.png" , FileHandler.FILEMODE_READONLY);
				Image image = Image.load(imageFile);
				image.loadFrame(0);
				RectF rect = new RectF(100, 100, 200, 200);
				Signature signature = page.addSignature(rect);
				signature.setDefaultContentsLength(20000);
				signature.initValue();
				KeyStoreInfo ksInfo = new KeyStoreInfo(KeyStoreInfo.TYPE_PKCS12, inputCertFile, certFileKey.getBytes());				
				signature.setKeyStoreInfo(ksInfo);
				signature.setImage(image);
				signature.setText("sign demo");
				signature.setFilter("Adobe.PPKLite");
				signature.setSubFilter("adbe.pkcs7.detached");
				signature.setAppearanceFlags(signature.APPEARANCE_IMAGE|signature.APPEARANCE_TEXT);
				signature.resetAppearance();
				
				FileHandler signedFile = FileHandler.create(outputFloder + "/sign_demo.pdf", FileHandler.FILEMODE_TRUNCATE);
				Progress progress = signature.startSign(signedFile);
				if(progress != null)
				{
					int ret = Progress.TOBECONTINUED; 
					while (ret == Progress.TOBECONTINUED)
					{
					 ret = progress.continueProgress(0);
					} 
					progress.release();
				}
				signedFile.release();
				image.release();
				imageFile.release();
				document.closePage(page);
				document.close();
			} catch (PDFException e) {
				// TODO Auto-generated catch block
				Common.outputErrMsg(e.getLastError(), "Failed to sign PDF document file.");
				e.printStackTrace();
			}
		}
}
